package net.pricefx.formulaengine.scripting.inputbuilder;

import net.pricefx.common.api.InputType;
import net.pricefx.common.api.PriceFxInterface;

/**
 * Builder class for input type DateRangeUserEntry {@link InputType#DATERANGEUSERENTRY}.
 */
public class DateRangeInputBuilder extends AbstractInputBuilder<DateRangeInputBuilder, String[]> {

    protected DateRangeInputBuilder(InputBuilderContext builderContext, String paramName) {
        super(builderContext, InputType.DATERANGEUSERENTRY, paramName);
    }

    /**
     * Set from value of the configuration parameters.
     * <p>Example:
     * <blockquote><pre>
     * api.inputBuilderFactory()
     *      .createDateRangeUserEntry("dateRange")
     *      .setFrom("2019-10-01")
     *      .setTo("2019-11-01")
     *      .buildContextParameter()
     * </pre></blockquote>
     *
     * @param from Date from, as a String
     * @return self
     */
    public DateRangeInputBuilder setFrom(String from) {
        cp.addParameterConfigEntry(PriceFxInterface.FIELD_CONTEXTPARAM_CONFIG_FROM, from);
        return this;
    }

    /**
     * Set to value of the configuration parameters.
     * <p>Example:
     * <blockquote><pre>
     * api.inputBuilderFactory()
     *      .createDateRangeUserEntry("dateRange")
     *      .setFrom("2019-10-01")
     *      .setTo("2019-11-01")
     *      .buildContextParameter()
     * </pre></blockquote>
     *
     * @param to Date to, as a String
     * @return self
     */
    public DateRangeInputBuilder setTo(String to) {
        cp.addParameterConfigEntry(PriceFxInterface.FIELD_CONTEXTPARAM_CONFIG_TO, to);
        return this;
    }

}
