package net.pricefx.formulaengine.scripting.inputbuilder;

import net.pricefx.common.api.InputType;
import net.pricefx.server.dto.calculation.ContextParameter;

public class RowInputBuilder<T> extends AbstractInputBuilder<RowInputBuilder, T> {
    public RowInputBuilder(InputBuilderContext builderContext, String name) {
        super(builderContext, InputType.ROW, name);
    }

    @Override
    protected Object _getInput() {
        return null;
    }

    /**
     * Add new input for InputBuilder.
     * <p>Example:
     * <blockquote><pre>
     * def configurator = api.createConfiguratorEntry()
     *
     * configurator.createParameter(
     *      api.inputBuilderFactory()
     *         .createRowLayout("Row")
     *         .addInput(
     *              api.inputBuilderFactory()
     *                  .createStringUserEntry("StringEntry")
     *                  .setTextMask("Enter some string :)")
     *                  .setLabel("A String entry with refresh")
     *                  .buildContextParameter())
     *          .buildContextParameter()
     * </pre></blockquote>
     *
     * @param contextParameter ContextParameter to be added
     * @return self
     */
    public RowInputBuilder<T> addInput(ContextParameter contextParameter) {
        cp.addInput(contextParameter);
        return this;
    }
}
